@@ -1,9 +1,9 @@
 opar = par (ask = dev.interactive (orNone = TRUE) )
 
-data (computer)
-Computer.df = computer
-attach(Computer.df)
-Computer.df
+data(computer.df)
+
+attach(computer.df)
+computer.df
 selfassess<-factor(selfassess)
 stripchart(score~selfassess,pch=1,vert=T,main="Stripcharts of Selfassess",ylab="score")
 numerical.summary(score~selfassess)
@@ -14,6 +14,7 @@ shapiro.test(residuals(computer.fit))
 summary.1way(computer.fit)
 multiple.comp(computer.fit)
 
+detach(computer.df)
 par (opar)
 
 
