@@ -1,8 +1,7 @@
 opar = par (ask = dev.interactive (orNone = TRUE) )
 
-data (oyster)
-Oyster.df = oyster
-attach(Oyster.df)
+data (oyster.fd)
+attach(oyster.df)
 Site<-factor(Site)
 boxplot(Oysters~Site,ylab="Number of Oysters",main="Boxplot of Oysters by Site")
 levene.test(Oysters~Site)
@@ -14,6 +13,7 @@ shapiro.test(residuals(oyster.fit))
 summary.1way(oyster.fit)
 multiple.comp(oyster.fit)
 
+detach(oyster.df)
 par (opar)
 
 
