@@ -1,7 +1,6 @@
 opar = par (ask = dev.interactive (orNone = TRUE) )
 
-data (camplake)
-camplake.df = camplake
+data (camplake.df)
 attach(camplake.df)
 Age.F<-factor(Age)
 plot(Length~Scale.Radius,type="n",main="Length vs Scale radius (by Age)")
@@ -11,8 +10,9 @@ resid.plot(bluegill.fit,f=0.7)
 plot(bluegill.fit,which=2)
 shapiro.test(residuals(bluegill.fit))
 summary(bluegill.fit)
-ci.reg(bluegill.fit) 
+ci.reg(bluegill.fit)
 
+detach(camplake.df)
 par (opar)
 
 
