@@ -1,9 +1,7 @@
 opar = par (ask = dev.interactive (orNone = TRUE) )
 
-data (incomes)
-Incomes.df = incomes
-remove (incomes)
-attach(Incomes.df)
+data (incomes.df)
+attach(incomes.df)
 incomes
 layout.20x(1,2)
 hist(incomes)
@@ -28,6 +26,7 @@ c.i.
 exp(c.i.)
 layout.20x(1,1)
 
+detach(incomes.df)
 par (opar)
 
 
